@@ -170,7 +170,7 @@ def get(id, **kwargs):
     url = obis_baseurl + "occurrence/" + str(id)
     args = {}
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def search(
@@ -287,7 +287,7 @@ def search(
         "size": size,
         "hasextensions": hasextensions,
     }
-    return OccResponse(url, args, isSearch=True, hasMapper=True, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=True, hasMapper=True, isKML=False)
 
 
 def grid(
@@ -366,9 +366,9 @@ def grid(
     }
     if not geojson:
         url += "/kml"
-        return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=True)
+        return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=True)
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def getpoints(
@@ -445,7 +445,7 @@ def getpoints(
         "exclude": exclude,
     }
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args, **kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def point(
@@ -528,7 +528,7 @@ def point(
         "exclude": exclude,
     }
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def tile(
@@ -612,9 +612,9 @@ def tile(
     }
     if mvt:
         url += ".mvt"
-        return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=True)
+        return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=True)
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def centroid(
@@ -687,7 +687,7 @@ def centroid(
         "exclude": exclude,
     }
 
-    return OccResponse(url, args, isSearch=False, hasMapper=False, isKML=False)
+    return OccResponse(url, {**args,**kwargs}, isSearch=False, hasMapper=False, isKML=False)
 
 
 def lookup_taxon(scientificname):
